state_machine library

Classes

Event
Event is a type of data the StateMachine reacts to.
State
State represents a distinct state of the StateMachine.
StateMachine
StateMachine is used to describe the automaton on the basis of which the source code of the state machine is generated.
Transition