parameters property

Map<String, String> parameters
final

Parameters of the State.

State parameters are intended solely for storing public data reflecting the current state. They are completely unnecessary for the proper operation of the state machine.

The values ​​for the parameters (arguments) are automatically filled in from the arguments passed in the Event instance.
The mapping of parameters is performed by name.
For parameters that do not have parameters of the same name in the Event, it is necessary to specify arguments in the Transition.
To explicitly specify arbitrary values, the argument values ​​in the Transition must also be specified.

Implementation

final Map<String, String> parameters;