Transition class

Constructors

Transition({String? action, Map<String, String> arguments = const {}, required Event event, String? guard, required State source, required State target})

Properties

action String?
Source code of the action.
getter/setter pair
arguments Map<String, String>
Transition arguments.
The arguments specified in the transition are used to fill in the values ​of the state parameters.
final
event Event
The event that accepts this transition.
final
guard String?
Source code of the guard expression.
final
hashCode int
The hash code for this object.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source State
The state from which the transition is performed.
final
target State
The state to which the transition is performed.
final

Methods

difference(Transition other) → (String, (Object?, Object?))?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override