action property

String? action
getter/setter pair

Source code of the action.

The main purpose is to prepare the arguments used to create the State instance before transitioning to the next state.

Implementation

String? action;