StateMachineBuilder class

Constructors

StateMachineBuilder({required String initialState})

Properties

events List<Event>
no setter
hashCode int
The hash code for this object.
no setterinherited
initialState String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
states List<State>
no setter
transitions Transitions
no setter

Methods

addEvent(String name, {String? description, String? fillName, bool? isCommand, Map<String, String> parameters = const {}}) Event
addState(String name, {bool hasAction = false, Map<String, String> parameters = const {}}) State
addTransition({Map<String, String> arguments = const {}, String? action, required String from, String? guard, required String on, required String to}) Transition
build() → ({State initialState, Transitions transitions})
getEvent(String name) Event
getState(String name) State
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited