StateMachineToGraphvizConverter class

Constructors

StateMachineToGraphvizConverter({required StateMachine stateMachine})

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stateMachine StateMachine
finalinherited

Methods

addFooter(StringBuffer buffer) → void
addHeader(StringBuffer buffer) → void
addState(StringBuffer buffer, State state, {bool isInitial = false}) → void
addTransition(StringBuffer buffer, Transition transition) → void
buildStateLabel(State state) String
inherited
buildTransitionLabel(Transition transition) String
inherited
convert() String
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
writeAction(StringBuffer buffer, String action) → void
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited