Event class
Event is a type of data the StateMachine reacts to.
Also acts as a Command enum value if the event is not private.
Constructors
Properties
- description ↔ String?
-
The description of the
command.getter/setter pair - fullName ↔ String?
-
The name of the
command.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- isCommand → bool?
-
Indicates whether the event is a command, otherwise it will be determined
automatically when generating the state machine.
final
- name → String
-
The name of the Event.
final
-
parameters
→ Map<
String, String> -
Parameters of the Event.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited