State class
State represents a distinct state of the StateMachine.
A StateMachine can only be in one State at any given time. It changes from one State to another via transitions triggered by the Event.
Constructors
Properties
- hasAction → bool
-
Indicates that the state has an action ath ete state machine level.
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- name → String
-
The name of the State.
final
-
parameters
→ Map<
String, String> -
Parameters of the State.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override