StateMachine class
StateMachine is used to describe the automaton on the basis of which the source code of the state machine is generated.
Constructors
- StateMachine({required String commandType, String eventPrefix = '', String eventSuffix = 'Event', required String eventType, String? fields, String? globals, required State initialState, String? methods, required String name, String statePrefix = '', String stateSuffix = 'State', required String stateType, required Transitions transitions})
Properties
- commandType → String
-
The name of the enum type for
Commandfinal - eventPrefix → String
-
Type name prefix for a specific Event type
final
- eventSuffix → String
-
Type name suffix for a specific Event type
final
- eventType → String
-
The name of the base type for Event
final
- fields ↔ String?
-
Source code of the state machine class fields.
getter/setter pair
- globals ↔ String?
-
Top-level source code of the state machine library.
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- initialState → State
-
Initial state of the state machine.
final
- methods ↔ String?
-
Source code of the state machine class methods.
getter/setter pair
- name → String
-
Name of the state machine class.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statePrefix → String
-
Type name prefix for a specific State type
final
- stateSuffix → String
-
Type name suffix for a specific State type
final
- stateType → String
-
The name of the base type for State
final
- transitions → Transitions
-
Transition of the state machine.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited