Transition class
Properties
-
action
↔ String?
-
Source code of the action.
getter/setter pair
-
arguments
→ Map<String, String>
-
Transition arguments.
The arguments specified in the transition are used to fill in the values
of the state parameters.
final
-
event
→ Event
-
The event that accepts this transition.
final
-
guard
→ String?
-
Source code of the
guard expression.
final
-
hashCode
→ int
-
The hash code for this object.
no setteroverride
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
-
source
→ State
-
The state from which the transition is performed.
final
-
target
→ State
-
The state to which the transition is performed.
final